@@ -16,7 +16,7 @@ rom="""if not terminating:
     bcs = params.BoundaryConditions()
     bcs.add_velocities(face_name=str(inlet),file_name='{}'+os.sep+'{}')
     for face_name in outlets:
-        bcs.add_resistance(face_name=str(face_name),resistance=((1/resistance[face_name])/total_res)*outlet_res_total)
+        bcs.add_resistance(face_name=str(face_name),resistance=((1/resistance[face_name])/total_res)*0+outlet_res_total)
     solution_params = params.Solution()
     solution_params.time_step = {}
     solution_params.num_time_steps = {}
@@ -60,7 +60,20 @@ rom="""if not terminating:
         rom_view_file += 'for vessel in vessels:\\n'
         rom_view_file += '    ax_flow.plot(data["time"],data["flow"][vessel][0],label="vessel_"+str(vessel))\\n'
         rom_view_file += '    ax_pressure.plot(data["time"],data["pressure"][vessel][0]/1333.22,label="vessel_"+str(vessel))\\n'
-        rom_view_file += 'for vessel in {{}}:\\n'.format(outlets)
+        rom_view_file += 'import json\\n'
+        rom_view_file += 'info = json.load(open("solver_0d.in"))\\n'
+        rom_view_file += 'all_inlets = []\\n'
+        rom_view_file += 'all_outlets = []\\n'
+        rom_view_file += 'for i in info["junctions"]:\\n'
+        rom_view_file += '    for j in i["inlet_vessels"]:\\n'
+        rom_view_file += '        all_inlets.append(j)\\n'
+        rom_view_file += '    for j in i["outlet_vessels"]:\\n'
+        rom_view_file += '        all_outlets.append(j)\\n'
+        rom_view_file += 'all_inlets = set(all_inlets)\\n'
+        rom_view_file += 'all_outlets = set(all_outlets)\\n'
+        rom_view_file += 'true_outlets = list(all_outlets.difference(all_inlets))\\n'
+        rom_view_file += 'true_inlets = list(all_inlets.difference(all_outlets))\\n'
+        rom_view_file += 'for vessel in true_outlets:\\n'
         rom_view_file += '    ax_flow_outlets.plot(data["time"],data["flow"][vessel][-1],label="vessel_"+str(vessel))\\n'
         rom_view_file += '    ax_pressure_outlets.plot(data["time"],data["pressure"][vessel][-1]/1333.22,label="vessel_"+str(vessel))\\n'
         rom_view_file += 'ax_flow.set_xlabel("Time (sec)")\\n'
@@ -87,8 +100,10 @@ rom="""if not terminating:
             search_path = 'C:\\\\Program Files\\\\SimVascular'
             files = glob(search_path+'\\\\**\\\\svOneDSolver.exe',recursive=True)
             if len(files) > 0:
+                isfile = [os.path.isfile(f) for f in files]
+                only_files = [files[of] for of in isfile]
                 print('OneDSolver Found!')
-                shutil.copy(files[0],oneD_folder)
+                shutil.copy(only_files[0],oneD_folder)
             else:
                 print('OneDSolver not found (will require user-specified executable location)')
         elif platform.system() == 'Linux':
@@ -98,8 +113,10 @@ rom="""if not terminating:
                 search_dir = '/usr/local/sv'
                 files = glob(search_dir+'/**/OneDSolver',recursive=True)
                 if len(files) > 0:
+                    isfile = [os.path.isfile(f) for f in files]
+                    only_files = [files[of] for of in isfile]
                     print('OneDSolver Found!')
-                    shutil.copy(files[0],oneD_folder)
+                    shutil.copy(only_files[0],oneD_folder)
                 else:
                     print('OneDSolver not found (will require user-specified executable location)')
             else:
@@ -107,8 +124,10 @@ rom="""if not terminating:
                 search_dir = '/usr/local/sv'
                 files = glob(search_dir+'/**/OneDSolver',recursive=True)
                 if len(files) > 0:
+                    isfile = [os.path.isfile(f) for f in files]
+                    only_files = [files[of] for of in isfile]
                     print('OneDSolver Found!')
-                    shutil.copy(files[0],oneD_folder)
+                    shutil.copy(only_files[0],oneD_folder)
                 else:
                     print('OneDSolver not found (will require user-specified executable location)')
         elif platform.system() == 'Darwin':
@@ -116,8 +135,10 @@ rom="""if not terminating:
             search_dir = '/usr/local/sv'
             files = glob(search_dir+'/**/OneDSolver',recursive=True)
             if len(files) > 0:
+                isfile = [os.path.isfile(f) for f in files]
+                only_files = [files[of] for of in isfile]
                 print('OneDSolver Found!')
-                shutil.copy(files[0],oneD_folder)
+                shutil.copy(only_files[0],oneD_folder)
             else:
                 print('OneDSolver not found (will require user-specified executable location)')
 """
